-- ip4r extension

-- complain if script is sourced in psql, rather than via CREATE EXTENSION
\echo Use "CREATE EXTENSION ip4r" to load this file. \quit

ALTER EXTENSION ip4r ADD FUNCTION ip4_in(cstring);
ALTER EXTENSION ip4r ADD FUNCTION ip4_out(ip4);
ALTER EXTENSION ip4r ADD FUNCTION ip4_recv(internal);
ALTER EXTENSION ip4r ADD FUNCTION ip4_send(ip4);
ALTER EXTENSION ip4r ADD TYPE ip4;
ALTER EXTENSION ip4r ADD FUNCTION ip4r_in(cstring);
ALTER EXTENSION ip4r ADD FUNCTION ip4r_out(ip4r);
ALTER EXTENSION ip4r ADD FUNCTION ip4r_recv(internal);
ALTER EXTENSION ip4r ADD FUNCTION ip4r_send(ip4r);
ALTER EXTENSION ip4r ADD TYPE ip4r;
ALTER EXTENSION ip4r ADD FUNCTION ip6_in(cstring);
ALTER EXTENSION ip4r ADD FUNCTION ip6_out(ip6);
ALTER EXTENSION ip4r ADD FUNCTION ip6_recv(internal);
ALTER EXTENSION ip4r ADD FUNCTION ip6_send(ip6);
ALTER EXTENSION ip4r ADD TYPE ip6;
ALTER EXTENSION ip4r ADD FUNCTION ip6r_in(cstring);
ALTER EXTENSION ip4r ADD FUNCTION ip6r_out(ip6r);
ALTER EXTENSION ip4r ADD FUNCTION ip6r_recv(internal);
ALTER EXTENSION ip4r ADD FUNCTION ip6r_send(ip6r);
ALTER EXTENSION ip4r ADD TYPE ip6r;
ALTER EXTENSION ip4r ADD FUNCTION ipaddress_in(cstring);
ALTER EXTENSION ip4r ADD FUNCTION ipaddress_out(ipaddress);
ALTER EXTENSION ip4r ADD FUNCTION ipaddress_recv(internal);
ALTER EXTENSION ip4r ADD FUNCTION ipaddress_send(ipaddress);
ALTER EXTENSION ip4r ADD TYPE ipaddress;
ALTER EXTENSION ip4r ADD FUNCTION iprange_in(cstring);
ALTER EXTENSION ip4r ADD FUNCTION iprange_out(iprange);
ALTER EXTENSION ip4r ADD FUNCTION iprange_recv(internal);
ALTER EXTENSION ip4r ADD FUNCTION iprange_send(iprange);
ALTER EXTENSION ip4r ADD TYPE iprange;
ALTER EXTENSION ip4r ADD FUNCTION ip4(bigint);
ALTER EXTENSION ip4r ADD FUNCTION ip4(double precision);
ALTER EXTENSION ip4r ADD FUNCTION ip4(numeric);
ALTER EXTENSION ip4r ADD FUNCTION ip4(inet);
ALTER EXTENSION ip4r ADD FUNCTION ip4(text);
ALTER EXTENSION ip4r ADD FUNCTION ip4(ipaddress);
ALTER EXTENSION ip4r ADD FUNCTION ip6(numeric);
ALTER EXTENSION ip4r ADD FUNCTION ip6(inet);
ALTER EXTENSION ip4r ADD FUNCTION ip6(text);
ALTER EXTENSION ip4r ADD FUNCTION ip6(ipaddress);
ALTER EXTENSION ip4r ADD FUNCTION ipaddress(inet);
ALTER EXTENSION ip4r ADD FUNCTION ipaddress(ip4);
ALTER EXTENSION ip4r ADD FUNCTION ipaddress(ip6);
ALTER EXTENSION ip4r ADD FUNCTION ipaddress(text);
ALTER EXTENSION ip4r ADD FUNCTION ip4r(cidr);
ALTER EXTENSION ip4r ADD FUNCTION ip4r(ip4);
ALTER EXTENSION ip4r ADD FUNCTION ip4r(text);
ALTER EXTENSION ip4r ADD FUNCTION ip4r(iprange);
ALTER EXTENSION ip4r ADD FUNCTION ip6r(cidr);
ALTER EXTENSION ip4r ADD FUNCTION ip6r(ip6);
ALTER EXTENSION ip4r ADD FUNCTION ip6r(text);
ALTER EXTENSION ip4r ADD FUNCTION ip6r(iprange);
ALTER EXTENSION ip4r ADD FUNCTION iprange(cidr);
ALTER EXTENSION ip4r ADD FUNCTION iprange(ip4);
ALTER EXTENSION ip4r ADD FUNCTION iprange(ip6);
ALTER EXTENSION ip4r ADD FUNCTION iprange(ip4r);
ALTER EXTENSION ip4r ADD FUNCTION iprange(ip6r);
ALTER EXTENSION ip4r ADD FUNCTION iprange(ipaddress);
ALTER EXTENSION ip4r ADD FUNCTION iprange(text);
ALTER EXTENSION ip4r ADD FUNCTION cidr(ip4);
ALTER EXTENSION ip4r ADD FUNCTION cidr(ip4r);
ALTER EXTENSION ip4r ADD FUNCTION cidr(ip6);
ALTER EXTENSION ip4r ADD FUNCTION cidr(ip6r);
ALTER EXTENSION ip4r ADD FUNCTION cidr(ipaddress);
ALTER EXTENSION ip4r ADD FUNCTION cidr(iprange);
ALTER EXTENSION ip4r ADD FUNCTION text(ip4);
ALTER EXTENSION ip4r ADD FUNCTION text(ip4r);
ALTER EXTENSION ip4r ADD FUNCTION text(ip6);
ALTER EXTENSION ip4r ADD FUNCTION text(ip6r);
ALTER EXTENSION ip4r ADD FUNCTION text(ipaddress);
ALTER EXTENSION ip4r ADD FUNCTION text(iprange);
ALTER EXTENSION ip4r ADD FUNCTION to_bigint(ip4);
ALTER EXTENSION ip4r ADD FUNCTION to_double(ip4);
ALTER EXTENSION ip4r ADD FUNCTION to_numeric(ip4);
ALTER EXTENSION ip4r ADD FUNCTION to_numeric(ip6);
ALTER EXTENSION ip4r ADD FUNCTION to_numeric(ipaddress);
ALTER EXTENSION ip4r ADD CAST (ip4 as bigint);
ALTER EXTENSION ip4r ADD CAST (ip4 as double precision);
ALTER EXTENSION ip4r ADD CAST (ip4 as numeric);
ALTER EXTENSION ip4r ADD CAST (ip4 as text);
ALTER EXTENSION ip4r ADD CAST (ip4 as cidr);
ALTER EXTENSION ip4r ADD CAST (ip4r as cidr);
ALTER EXTENSION ip4r ADD CAST (ip4r as text);
ALTER EXTENSION ip4r ADD CAST (ip6 as numeric);
ALTER EXTENSION ip4r ADD CAST (ip6 as text);
ALTER EXTENSION ip4r ADD CAST (ip6 as cidr);
ALTER EXTENSION ip4r ADD CAST (ip6r as cidr);
ALTER EXTENSION ip4r ADD CAST (ip6r as text);
ALTER EXTENSION ip4r ADD CAST (ipaddress as numeric);
ALTER EXTENSION ip4r ADD CAST (ipaddress as text);
ALTER EXTENSION ip4r ADD CAST (ipaddress as cidr);
ALTER EXTENSION ip4r ADD CAST (iprange as cidr);
ALTER EXTENSION ip4r ADD CAST (iprange as text);
ALTER EXTENSION ip4r ADD CAST (text as ip4);
ALTER EXTENSION ip4r ADD CAST (text as ip4r);
ALTER EXTENSION ip4r ADD CAST (text as ip6);
ALTER EXTENSION ip4r ADD CAST (text as ip6r);
ALTER EXTENSION ip4r ADD CAST (text as ipaddress);
ALTER EXTENSION ip4r ADD CAST (text as iprange);
ALTER EXTENSION ip4r ADD CAST (bigint as ip4);
ALTER EXTENSION ip4r ADD CAST (double precision as ip4);
ALTER EXTENSION ip4r ADD CAST (numeric as ip4);
ALTER EXTENSION ip4r ADD CAST (numeric as ip6);
ALTER EXTENSION ip4r ADD CAST (cidr as ip4r);
ALTER EXTENSION ip4r ADD CAST (cidr as ip6r);
ALTER EXTENSION ip4r ADD CAST (cidr as iprange);
ALTER EXTENSION ip4r ADD CAST (inet as ip4);
ALTER EXTENSION ip4r ADD CAST (inet as ip6);
ALTER EXTENSION ip4r ADD CAST (inet as ipaddress);
ALTER EXTENSION ip4r ADD CAST (ip4 as ip4r);
ALTER EXTENSION ip4r ADD CAST (ip4 as ipaddress);
ALTER EXTENSION ip4r ADD CAST (ip4 as iprange);
ALTER EXTENSION ip4r ADD CAST (ip4r as iprange);
ALTER EXTENSION ip4r ADD CAST (ip6 as ip6r);
ALTER EXTENSION ip4r ADD CAST (ip6 as ipaddress);
ALTER EXTENSION ip4r ADD CAST (ip6 as iprange);
ALTER EXTENSION ip4r ADD CAST (ip6r as iprange);
ALTER EXTENSION ip4r ADD CAST (ipaddress as iprange);
ALTER EXTENSION ip4r ADD CAST (ipaddress as ip4);
ALTER EXTENSION ip4r ADD CAST (ipaddress as ip6);
ALTER EXTENSION ip4r ADD CAST (iprange as ip4r);
ALTER EXTENSION ip4r ADD CAST (iprange as ip6r);
ALTER EXTENSION ip4r ADD FUNCTION ip4r(ip4,ip4);
ALTER EXTENSION ip4r ADD FUNCTION ip6r(ip6,ip6);
ALTER EXTENSION ip4r ADD FUNCTION iprange(ip4,ip4);
ALTER EXTENSION ip4r ADD FUNCTION iprange(ip6,ip6);
ALTER EXTENSION ip4r ADD FUNCTION iprange(ipaddress,ipaddress);
ALTER EXTENSION ip4r ADD FUNCTION family(ip4);
ALTER EXTENSION ip4r ADD FUNCTION family(ip4r);
ALTER EXTENSION ip4r ADD FUNCTION family(ip6);
ALTER EXTENSION ip4r ADD FUNCTION family(ip6r);
ALTER EXTENSION ip4r ADD FUNCTION family(ipaddress);
ALTER EXTENSION ip4r ADD FUNCTION family(iprange);
ALTER EXTENSION ip4r ADD FUNCTION ip4_netmask(integer);
ALTER EXTENSION ip4r ADD FUNCTION ip6_netmask(integer);
ALTER EXTENSION ip4r ADD FUNCTION is_cidr(ip4r);
ALTER EXTENSION ip4r ADD FUNCTION is_cidr(ip6r);
ALTER EXTENSION ip4r ADD FUNCTION is_cidr(iprange);
ALTER EXTENSION ip4r ADD FUNCTION masklen(ip4r);
ALTER EXTENSION ip4r ADD FUNCTION masklen(ip6r);
ALTER EXTENSION ip4r ADD FUNCTION masklen(iprange);
ALTER EXTENSION ip4r ADD FUNCTION lower(ip4r);
ALTER EXTENSION ip4r ADD FUNCTION lower(ip6r);
ALTER EXTENSION ip4r ADD FUNCTION lower(iprange);
ALTER EXTENSION ip4r ADD FUNCTION upper(ip4r);
ALTER EXTENSION ip4r ADD FUNCTION upper(ip6r);
ALTER EXTENSION ip4r ADD FUNCTION upper(iprange);
ALTER EXTENSION ip4r ADD FUNCTION ip4_net_lower(ip4,integer);
ALTER EXTENSION ip4r ADD FUNCTION ip6_net_lower(ip6,integer);
ALTER EXTENSION ip4r ADD FUNCTION ipaddress_net_lower(ipaddress,integer);
ALTER EXTENSION ip4r ADD FUNCTION ip4_net_upper(ip4,integer);
ALTER EXTENSION ip4r ADD FUNCTION ip6_net_upper(ip6,integer);
ALTER EXTENSION ip4r ADD FUNCTION ipaddress_net_upper(ipaddress,integer);
ALTER EXTENSION ip4r ADD FUNCTION ip4r_union(ip4r, ip4r);
ALTER EXTENSION ip4r ADD FUNCTION ip6r_union(ip6r, ip6r);
ALTER EXTENSION ip4r ADD FUNCTION iprange_union(iprange, iprange);
ALTER EXTENSION ip4r ADD FUNCTION ip4r_inter(ip4r,ip4r);
ALTER EXTENSION ip4r ADD FUNCTION ip6r_inter(ip6r,ip6r);
ALTER EXTENSION ip4r ADD FUNCTION iprange_inter(iprange,iprange);
ALTER EXTENSION ip4r ADD FUNCTION ip4r_net_mask(ip4,ip4);
ALTER EXTENSION ip4r ADD FUNCTION ip6r_net_mask(ip6,ip6);
ALTER EXTENSION ip4r ADD FUNCTION iprange_net_mask(ip4,ip4);
ALTER EXTENSION ip4r ADD FUNCTION iprange_net_mask(ip6,ip6);
ALTER EXTENSION ip4r ADD FUNCTION iprange_net_mask(ipaddress,ipaddress);
ALTER EXTENSION ip4r ADD FUNCTION ip4r_net_prefix(ip4,integer);
ALTER EXTENSION ip4r ADD FUNCTION ip6r_net_prefix(ip6,integer);
ALTER EXTENSION ip4r ADD FUNCTION iprange_net_prefix(ip4,integer);
ALTER EXTENSION ip4r ADD FUNCTION iprange_net_prefix(ip6,integer);
ALTER EXTENSION ip4r ADD FUNCTION iprange_net_prefix(ipaddress,integer);
ALTER EXTENSION ip4r ADD OPERATOR /(ip4,ip4);
ALTER EXTENSION ip4r ADD OPERATOR /(ip6,ip6);
ALTER EXTENSION ip4r ADD OPERATOR /(ipaddress,ipaddress);
ALTER EXTENSION ip4r ADD OPERATOR /(ip4,integer);
ALTER EXTENSION ip4r ADD OPERATOR /(ip6,integer);
ALTER EXTENSION ip4r ADD OPERATOR /(ipaddress,integer);
ALTER EXTENSION ip4r ADD FUNCTION ip4r_size(ip4r);
ALTER EXTENSION ip4r ADD FUNCTION ip6r_size(ip6r);
ALTER EXTENSION ip4r ADD FUNCTION iprange_size(iprange);
ALTER EXTENSION ip4r ADD FUNCTION ip4r_size_exact(ip4r);
ALTER EXTENSION ip4r ADD FUNCTION ip6r_size_exact(ip6r);
ALTER EXTENSION ip4r ADD FUNCTION iprange_size_exact(iprange);
ALTER EXTENSION ip4r ADD OPERATOR @(NONE,ip4r);
ALTER EXTENSION ip4r ADD OPERATOR @(NONE,ip6r);
ALTER EXTENSION ip4r ADD OPERATOR @(NONE,iprange);
ALTER EXTENSION ip4r ADD OPERATOR @@(NONE,ip4r);
ALTER EXTENSION ip4r ADD OPERATOR @@(NONE,ip6r);
ALTER EXTENSION ip4r ADD OPERATOR @@(NONE,iprange);
ALTER EXTENSION ip4r ADD FUNCTION ip4_and(ip4,ip4);
ALTER EXTENSION ip4r ADD FUNCTION ip6_and(ip6,ip6);
ALTER EXTENSION ip4r ADD FUNCTION ipaddress_and(ipaddress,ipaddress);
ALTER EXTENSION ip4r ADD OPERATOR &(ip4,ip4);
ALTER EXTENSION ip4r ADD OPERATOR &(ip6,ip6);
ALTER EXTENSION ip4r ADD OPERATOR &(ipaddress,ipaddress);
ALTER EXTENSION ip4r ADD FUNCTION ip4_or(ip4,ip4);
ALTER EXTENSION ip4r ADD FUNCTION ip6_or(ip6,ip6);
ALTER EXTENSION ip4r ADD FUNCTION ipaddress_or(ipaddress,ipaddress);
ALTER EXTENSION ip4r ADD OPERATOR |(ip4,ip4);
ALTER EXTENSION ip4r ADD OPERATOR |(ip6,ip6);
ALTER EXTENSION ip4r ADD OPERATOR |(ipaddress,ipaddress);
ALTER EXTENSION ip4r ADD FUNCTION ip4_not(ip4);
ALTER EXTENSION ip4r ADD FUNCTION ip6_not(ip6);
ALTER EXTENSION ip4r ADD FUNCTION ipaddress_not(ipaddress);
ALTER EXTENSION ip4r ADD OPERATOR ~(NONE,ip4);
ALTER EXTENSION ip4r ADD OPERATOR ~(NONE,ip6);
ALTER EXTENSION ip4r ADD OPERATOR ~(NONE,ipaddress);
ALTER EXTENSION ip4r ADD FUNCTION ip4_xor(ip4,ip4);
ALTER EXTENSION ip4r ADD FUNCTION ip6_xor(ip6,ip6);
ALTER EXTENSION ip4r ADD FUNCTION ipaddress_xor(ipaddress,ipaddress);
ALTER EXTENSION ip4r ADD OPERATOR #(ip4,ip4);
ALTER EXTENSION ip4r ADD OPERATOR #(ip6,ip6);
ALTER EXTENSION ip4r ADD OPERATOR #(ipaddress,ipaddress);
ALTER EXTENSION ip4r ADD FUNCTION ip4_plus_bigint(ip4,bigint);
ALTER EXTENSION ip4r ADD FUNCTION ip4_plus_int(ip4,integer);
ALTER EXTENSION ip4r ADD FUNCTION ip4_plus_numeric(ip4,numeric);
ALTER EXTENSION ip4r ADD OPERATOR +(ip4,bigint);
ALTER EXTENSION ip4r ADD OPERATOR +(ip4,integer);
ALTER EXTENSION ip4r ADD OPERATOR +(ip4,numeric);
ALTER EXTENSION ip4r ADD FUNCTION ip6_plus_bigint(ip6,bigint);
ALTER EXTENSION ip4r ADD FUNCTION ip6_plus_int(ip6,integer);
ALTER EXTENSION ip4r ADD FUNCTION ip6_plus_numeric(ip6,numeric);
ALTER EXTENSION ip4r ADD OPERATOR +(ip6,bigint);
ALTER EXTENSION ip4r ADD OPERATOR +(ip6,integer);
ALTER EXTENSION ip4r ADD OPERATOR +(ip6,numeric);
ALTER EXTENSION ip4r ADD FUNCTION ipaddress_plus_bigint(ipaddress,bigint);
ALTER EXTENSION ip4r ADD FUNCTION ipaddress_plus_int(ipaddress,integer);
ALTER EXTENSION ip4r ADD FUNCTION ipaddress_plus_numeric(ipaddress,numeric);
ALTER EXTENSION ip4r ADD OPERATOR +(ipaddress,bigint);
ALTER EXTENSION ip4r ADD OPERATOR +(ipaddress,integer);
ALTER EXTENSION ip4r ADD OPERATOR +(ipaddress,numeric);
ALTER EXTENSION ip4r ADD FUNCTION ip4_minus_bigint(ip4,bigint);
ALTER EXTENSION ip4r ADD FUNCTION ip4_minus_int(ip4,integer);
ALTER EXTENSION ip4r ADD FUNCTION ip4_minus_numeric(ip4,numeric);
ALTER EXTENSION ip4r ADD OPERATOR -(ip4,bigint);
ALTER EXTENSION ip4r ADD OPERATOR -(ip4,integer);
ALTER EXTENSION ip4r ADD OPERATOR -(ip4,numeric);
ALTER EXTENSION ip4r ADD FUNCTION ip6_minus_bigint(ip6,bigint);
ALTER EXTENSION ip4r ADD FUNCTION ip6_minus_int(ip6,integer);
ALTER EXTENSION ip4r ADD FUNCTION ip6_minus_numeric(ip6,numeric);
ALTER EXTENSION ip4r ADD OPERATOR -(ip6,bigint);
ALTER EXTENSION ip4r ADD OPERATOR -(ip6,integer);
ALTER EXTENSION ip4r ADD OPERATOR -(ip6,numeric);
ALTER EXTENSION ip4r ADD FUNCTION ipaddress_minus_bigint(ipaddress,bigint);
ALTER EXTENSION ip4r ADD FUNCTION ipaddress_minus_int(ipaddress,integer);
ALTER EXTENSION ip4r ADD FUNCTION ipaddress_minus_numeric(ipaddress,numeric);
ALTER EXTENSION ip4r ADD OPERATOR -(ipaddress,bigint);
ALTER EXTENSION ip4r ADD OPERATOR -(ipaddress,integer);
ALTER EXTENSION ip4r ADD OPERATOR -(ipaddress,numeric);
ALTER EXTENSION ip4r ADD FUNCTION ip4_minus_ip4(ip4,ip4);
ALTER EXTENSION ip4r ADD FUNCTION ip6_minus_ip6(ip6,ip6);
ALTER EXTENSION ip4r ADD FUNCTION ipaddress_minus_ipaddress(ipaddress,ipaddress);
ALTER EXTENSION ip4r ADD OPERATOR -(ip4,ip4);
ALTER EXTENSION ip4r ADD OPERATOR -(ip6,ip6);
ALTER EXTENSION ip4r ADD OPERATOR -(ipaddress,ipaddress);
ALTER EXTENSION ip4r ADD FUNCTION ip4r_contained_by(ip4r,ip4r);
ALTER EXTENSION ip4r ADD FUNCTION ip6r_contained_by(ip6r,ip6r);
ALTER EXTENSION ip4r ADD FUNCTION iprange_contained_by(iprange,iprange);
ALTER EXTENSION ip4r ADD OPERATOR <<=(ip4r,ip4r);
ALTER EXTENSION ip4r ADD OPERATOR <<=(ip6r,ip6r);
ALTER EXTENSION ip4r ADD OPERATOR <<=(iprange,iprange);
ALTER EXTENSION ip4r ADD FUNCTION ip4r_contained_by_strict(ip4r,ip4r);
ALTER EXTENSION ip4r ADD FUNCTION ip6r_contained_by_strict(ip6r,ip6r);
ALTER EXTENSION ip4r ADD FUNCTION iprange_contained_by_strict(iprange,iprange);
ALTER EXTENSION ip4r ADD OPERATOR <<(ip4r,ip4r);
ALTER EXTENSION ip4r ADD OPERATOR <<(ip6r,ip6r);
ALTER EXTENSION ip4r ADD OPERATOR <<(iprange,iprange);
ALTER EXTENSION ip4r ADD FUNCTION ip4r_contains(ip4r,ip4r);
ALTER EXTENSION ip4r ADD FUNCTION ip6r_contains(ip6r,ip6r);
ALTER EXTENSION ip4r ADD FUNCTION iprange_contains(iprange,iprange);
ALTER EXTENSION ip4r ADD OPERATOR >>=(ip4r,ip4r);
ALTER EXTENSION ip4r ADD OPERATOR >>=(ip6r,ip6r);
ALTER EXTENSION ip4r ADD OPERATOR >>=(iprange,iprange);
ALTER EXTENSION ip4r ADD FUNCTION ip4r_contains_strict(ip4r,ip4r);
ALTER EXTENSION ip4r ADD FUNCTION ip6r_contains_strict(ip6r,ip6r);
ALTER EXTENSION ip4r ADD FUNCTION iprange_contains_strict(iprange,iprange);
ALTER EXTENSION ip4r ADD OPERATOR >>(ip4r,ip4r);
ALTER EXTENSION ip4r ADD OPERATOR >>(ip6r,ip6r);
ALTER EXTENSION ip4r ADD OPERATOR >>(iprange,iprange);
ALTER EXTENSION ip4r ADD FUNCTION ip4r_overlaps(ip4r,ip4r);
ALTER EXTENSION ip4r ADD FUNCTION ip6r_overlaps(ip6r,ip6r);
ALTER EXTENSION ip4r ADD FUNCTION iprange_overlaps(iprange,iprange);
ALTER EXTENSION ip4r ADD OPERATOR &&(ip4r,ip4r);
ALTER EXTENSION ip4r ADD OPERATOR &&(ip6r,ip6r);
ALTER EXTENSION ip4r ADD OPERATOR &&(iprange,iprange);
ALTER EXTENSION ip4r ADD FUNCTION ip4_contained_by(ip4,ip4r);
ALTER EXTENSION ip4r ADD FUNCTION ip4_contained_by(ip4,iprange);
ALTER EXTENSION ip4r ADD FUNCTION ip6_contained_by(ip6,ip6r);
ALTER EXTENSION ip4r ADD FUNCTION ip6_contained_by(ip6,iprange);
ALTER EXTENSION ip4r ADD FUNCTION ipaddress_contained_by(ipaddress,iprange);
ALTER EXTENSION ip4r ADD FUNCTION ip4_contains(ip4r,ip4);
ALTER EXTENSION ip4r ADD FUNCTION ip6_contains(ip6r,ip6);
ALTER EXTENSION ip4r ADD FUNCTION ip4_contains(iprange,ip4);
ALTER EXTENSION ip4r ADD FUNCTION ip6_contains(iprange,ip6);
ALTER EXTENSION ip4r ADD FUNCTION ipaddress_contains(iprange,ipaddress);
ALTER EXTENSION ip4r ADD FUNCTION ip4_eq(ip4,ip4);
ALTER EXTENSION ip4r ADD FUNCTION ip4r_eq(ip4r,ip4r);
ALTER EXTENSION ip4r ADD FUNCTION ip6_eq(ip6,ip6);
ALTER EXTENSION ip4r ADD FUNCTION ip6r_eq(ip6r,ip6r);
ALTER EXTENSION ip4r ADD FUNCTION ipaddress_eq(ipaddress,ipaddress);
ALTER EXTENSION ip4r ADD FUNCTION iprange_eq(iprange,iprange);
ALTER EXTENSION ip4r ADD OPERATOR =(ip4,ip4);
ALTER EXTENSION ip4r ADD OPERATOR =(ip4r,ip4r);
ALTER EXTENSION ip4r ADD OPERATOR =(ip6,ip6);
ALTER EXTENSION ip4r ADD OPERATOR =(ip6r,ip6r);
ALTER EXTENSION ip4r ADD OPERATOR =(ipaddress,ipaddress);
ALTER EXTENSION ip4r ADD OPERATOR =(iprange,iprange);
ALTER EXTENSION ip4r ADD FUNCTION ip4_ge(ip4,ip4);
ALTER EXTENSION ip4r ADD FUNCTION ip4r_ge(ip4r,ip4r);
ALTER EXTENSION ip4r ADD FUNCTION ip6_ge(ip6,ip6);
ALTER EXTENSION ip4r ADD FUNCTION ip6r_ge(ip6r,ip6r);
ALTER EXTENSION ip4r ADD FUNCTION ipaddress_ge(ipaddress,ipaddress);
ALTER EXTENSION ip4r ADD FUNCTION iprange_ge(iprange,iprange);
ALTER EXTENSION ip4r ADD OPERATOR >=(ip4,ip4);
ALTER EXTENSION ip4r ADD OPERATOR >=(ip4r,ip4r);
ALTER EXTENSION ip4r ADD OPERATOR >=(ip6,ip6);
ALTER EXTENSION ip4r ADD OPERATOR >=(ip6r,ip6r);
ALTER EXTENSION ip4r ADD OPERATOR >=(ipaddress,ipaddress);
ALTER EXTENSION ip4r ADD OPERATOR >=(iprange,iprange);
ALTER EXTENSION ip4r ADD FUNCTION ip4_gt(ip4,ip4);
ALTER EXTENSION ip4r ADD FUNCTION ip4r_gt(ip4r,ip4r);
ALTER EXTENSION ip4r ADD FUNCTION ip6_gt(ip6,ip6);
ALTER EXTENSION ip4r ADD FUNCTION ip6r_gt(ip6r,ip6r);
ALTER EXTENSION ip4r ADD FUNCTION ipaddress_gt(ipaddress,ipaddress);
ALTER EXTENSION ip4r ADD FUNCTION iprange_gt(iprange,iprange);
ALTER EXTENSION ip4r ADD OPERATOR >(ip4,ip4);
ALTER EXTENSION ip4r ADD OPERATOR >(ip4r,ip4r);
ALTER EXTENSION ip4r ADD OPERATOR >(ip6,ip6);
ALTER EXTENSION ip4r ADD OPERATOR >(ip6r,ip6r);
ALTER EXTENSION ip4r ADD OPERATOR >(ipaddress,ipaddress);
ALTER EXTENSION ip4r ADD OPERATOR >(iprange,iprange);
ALTER EXTENSION ip4r ADD FUNCTION ip4_le(ip4,ip4);
ALTER EXTENSION ip4r ADD FUNCTION ip4r_le(ip4r,ip4r);
ALTER EXTENSION ip4r ADD FUNCTION ip6_le(ip6,ip6);
ALTER EXTENSION ip4r ADD FUNCTION ip6r_le(ip6r,ip6r);
ALTER EXTENSION ip4r ADD FUNCTION ipaddress_le(ipaddress,ipaddress);
ALTER EXTENSION ip4r ADD FUNCTION iprange_le(iprange,iprange);
ALTER EXTENSION ip4r ADD OPERATOR <=(ip4,ip4);
ALTER EXTENSION ip4r ADD OPERATOR <=(ip4r,ip4r);
ALTER EXTENSION ip4r ADD OPERATOR <=(ip6,ip6);
ALTER EXTENSION ip4r ADD OPERATOR <=(ip6r,ip6r);
ALTER EXTENSION ip4r ADD OPERATOR <=(ipaddress,ipaddress);
ALTER EXTENSION ip4r ADD OPERATOR <=(iprange,iprange);
ALTER EXTENSION ip4r ADD FUNCTION ip4_lt(ip4,ip4);
ALTER EXTENSION ip4r ADD FUNCTION ip4r_lt(ip4r,ip4r);
ALTER EXTENSION ip4r ADD FUNCTION ip6_lt(ip6,ip6);
ALTER EXTENSION ip4r ADD FUNCTION ip6r_lt(ip6r,ip6r);
ALTER EXTENSION ip4r ADD FUNCTION ipaddress_lt(ipaddress,ipaddress);
ALTER EXTENSION ip4r ADD FUNCTION iprange_lt(iprange,iprange);
ALTER EXTENSION ip4r ADD OPERATOR <(ip4,ip4);
ALTER EXTENSION ip4r ADD OPERATOR <(ip4r,ip4r);
ALTER EXTENSION ip4r ADD OPERATOR <(ip6,ip6);
ALTER EXTENSION ip4r ADD OPERATOR <(ip6r,ip6r);
ALTER EXTENSION ip4r ADD OPERATOR <(ipaddress,ipaddress);
ALTER EXTENSION ip4r ADD OPERATOR <(iprange,iprange);
ALTER EXTENSION ip4r ADD FUNCTION ip4_neq(ip4,ip4);
ALTER EXTENSION ip4r ADD FUNCTION ip4r_neq(ip4r,ip4r);
ALTER EXTENSION ip4r ADD FUNCTION ip6_neq(ip6,ip6);
ALTER EXTENSION ip4r ADD FUNCTION ip6r_neq(ip6r,ip6r);
ALTER EXTENSION ip4r ADD FUNCTION ipaddress_neq(ipaddress,ipaddress);
ALTER EXTENSION ip4r ADD FUNCTION iprange_neq(iprange,iprange);
ALTER EXTENSION ip4r ADD OPERATOR <>(ip4,ip4);
ALTER EXTENSION ip4r ADD OPERATOR <>(ip4r,ip4r);
ALTER EXTENSION ip4r ADD OPERATOR <>(ip6,ip6);
ALTER EXTENSION ip4r ADD OPERATOR <>(ip6r,ip6r);
ALTER EXTENSION ip4r ADD OPERATOR <>(ipaddress,ipaddress);
ALTER EXTENSION ip4r ADD OPERATOR <>(iprange,iprange);
ALTER EXTENSION ip4r ADD FUNCTION ip4_cmp(ip4,ip4);
ALTER EXTENSION ip4r ADD FUNCTION ip4r_cmp(ip4r,ip4r);
ALTER EXTENSION ip4r ADD FUNCTION ip6_cmp(ip6,ip6);
ALTER EXTENSION ip4r ADD FUNCTION ip6r_cmp(ip6r,ip6r);
ALTER EXTENSION ip4r ADD FUNCTION ipaddress_cmp(ipaddress,ipaddress);
ALTER EXTENSION ip4r ADD FUNCTION iprange_cmp(iprange,iprange);
ALTER EXTENSION ip4r ADD OPERATOR CLASS btree_ip4_ops USING btree;
ALTER EXTENSION ip4r ADD OPERATOR CLASS btree_ip4r_ops USING btree;
ALTER EXTENSION ip4r ADD OPERATOR CLASS btree_ip6_ops USING btree;
ALTER EXTENSION ip4r ADD OPERATOR CLASS btree_ip6r_ops USING btree;
ALTER EXTENSION ip4r ADD OPERATOR CLASS btree_ipaddress_ops USING btree;
ALTER EXTENSION ip4r ADD OPERATOR CLASS btree_iprange_ops USING btree;
ALTER EXTENSION ip4r ADD FUNCTION ip4hash(ip4);
ALTER EXTENSION ip4r ADD FUNCTION ip6hash(ip6);
ALTER EXTENSION ip4r ADD FUNCTION ipaddresshash(ipaddress);
ALTER EXTENSION ip4r ADD FUNCTION ip4rhash(ip4r);
ALTER EXTENSION ip4r ADD FUNCTION ip6rhash(ip6r);
ALTER EXTENSION ip4r ADD FUNCTION iprangehash(iprange);
ALTER EXTENSION ip4r ADD OPERATOR CLASS hash_ip4_ops USING hash;
ALTER EXTENSION ip4r ADD OPERATOR CLASS hash_ip4r_ops USING hash;
ALTER EXTENSION ip4r ADD OPERATOR CLASS hash_ip6_ops USING hash;
ALTER EXTENSION ip4r ADD OPERATOR CLASS hash_ip6r_ops USING hash;
ALTER EXTENSION ip4r ADD OPERATOR CLASS hash_ipaddress_ops USING hash;
ALTER EXTENSION ip4r ADD OPERATOR CLASS hash_iprange_ops USING hash;
ALTER EXTENSION ip4r ADD FUNCTION gip4r_consistent(internal,ip4r,int4);
ALTER EXTENSION ip4r ADD FUNCTION gip4r_compress(internal);
ALTER EXTENSION ip4r ADD FUNCTION gip4r_decompress(internal);
ALTER EXTENSION ip4r ADD FUNCTION gip4r_penalty(internal,internal,internal);
ALTER EXTENSION ip4r ADD FUNCTION gip4r_picksplit(internal, internal);
ALTER EXTENSION ip4r ADD FUNCTION gip4r_union(internal, internal);
ALTER EXTENSION ip4r ADD FUNCTION gip4r_same(ip4r, ip4r, internal);
ALTER EXTENSION ip4r ADD FUNCTION gip6r_consistent(internal,ip6r,int4);
ALTER EXTENSION ip4r ADD FUNCTION gip6r_compress(internal);
ALTER EXTENSION ip4r ADD FUNCTION gip6r_decompress(internal);
ALTER EXTENSION ip4r ADD FUNCTION gip6r_penalty(internal,internal,internal);
ALTER EXTENSION ip4r ADD FUNCTION gip6r_picksplit(internal, internal);
ALTER EXTENSION ip4r ADD FUNCTION gip6r_union(internal, internal);
ALTER EXTENSION ip4r ADD FUNCTION gip6r_same(ip6r, ip6r, internal);
ALTER EXTENSION ip4r ADD FUNCTION gipr_consistent(internal,iprange,int4);
ALTER EXTENSION ip4r ADD FUNCTION gipr_compress(internal);
ALTER EXTENSION ip4r ADD FUNCTION gipr_decompress(internal);
ALTER EXTENSION ip4r ADD FUNCTION gipr_penalty(internal,internal,internal);
ALTER EXTENSION ip4r ADD FUNCTION gipr_picksplit(internal, internal);
ALTER EXTENSION ip4r ADD FUNCTION gipr_union(internal, internal);
ALTER EXTENSION ip4r ADD FUNCTION gipr_same(iprange, iprange, internal);
ALTER EXTENSION ip4r ADD OPERATOR CLASS gist_ip4r_ops USING gist;
ALTER EXTENSION ip4r ADD OPERATOR CLASS gist_ip6r_ops USING gist;
ALTER EXTENSION ip4r ADD OPERATOR CLASS gist_iprange_ops USING gist;

-- end
